==> h4h5tools-2.2.1.tar.gz: h4h5tools-2.2.1/config/cmake/cacheinit.cmake <==
# This is the CMakeCache file.

########################
# EXTERNAL cache entries
########################

SET (BUILD_SHARED_LIBS ON CACHE BOOL "Build Shared Libraries" FORCE)

SET (USE_SHARED_LIBS ON CACHE BOOL "Use Shared Libraries" FORCE)

SET (BUILD_TESTING ON CACHE BOOL "Build H4H5 Unit Testing" FORCE)

SET (HDF_BUILD_EXAMPLES ON CACHE BOOL "Build H4H5 Library Examples" FORCE)

SET (HDF_BUILD_TOOLS ON CACHE BOOL "Build H4H5 Tools" FORCE)

SET (HDF_BUILD_UTILS ON CACHE BOOL "Build H4H5 Library Utilities" FORCE)

SET (H4H5_ENABLE_EOS2 ON CACHE BOOL "Allow conversions of HDF4-EOS2 files" FORCE)

SET (H4H5_TEST_HDFEOS2 OFF CACHE BOOL "Test H4H5 EOS Library Utility" FORCE)

SET (HDF_ENABLE_JPEG_LIB_SUPPORT ON CACHE BOOL "Enable Jpeg library" FORCE)

SET (HDF_ENABLE_Z_LIB_SUPPORT ON CACHE BOOL "Enable Zlib Filters" FORCE)

SET (HDF_ENABLE_SZIP_SUPPORT ON CACHE BOOL "Use SZip Filter" FORCE)

SET (HDF_ENABLE_SZIP_ENCODING ON CACHE BOOL "Use SZip Encoding" FORCE)

SET (USE_HDF5_16_API_DEFAULT OFF CACHE BOOL "Use the HDF5 1.6.x API" FORCE)

SET (HDF_DISABLE_COMPILER_WARNINGS OFF CACHE BOOL "Disable compiler warnings" FORCE)

SET (HDF_ENABLE_PARALLEL OFF CACHE BOOL "Enable parallel build (requires MPI)" FORCE)

SET (HDF_ENABLE_COVERAGE OFF CACHE BOOL "Enable code coverage for Libraries and Programs" FORCE)

SET (HDF_PACKAGE_EXTLIBS OFF CACHE BOOL "(WINDOWS)CPACK - include external libraries" FORCE)

SET (HDF_ALLOW_EXTERNAL_SUPPORT "NO" CACHE STRING "Allow External Library Building" FORCE)

SET (ZLIB_SVN_URL "http://svn.hdfgroup.uiuc.edu/zlib/trunk" CACHE STRING "Use ZLib from HDF repository" FORCE)

SET (SZIP_SVN_URL "http://svn.hdfgroup.uiuc.edu/szip/trunk" CACHE STRING "Use SZip from HDF repository" FORCE)

SET (JPEG_SVN_URL "http://svn.hdfgroup.uiuc.edu/jpeg/branches/jpeg8b" CACHE STRING "Use JPEG from HDF repository" FORCE)

SET (HDF4_SVN_URL "http://svn.hdfgroup.uiuc.edu/hdf4/trunk" CACHE STRING "Use HDF4 from HDF repository" FORCE)

SET (HDF5_SVN_URL "http://svn.hdfgroup.uiuc.edu/hdf5/branches/hdf5_1_8" CACHE STRING "Use HDF5 from HDF repository" FORCE)

SET (ZLIB_TGZ_NAME "ZLib.tar.gz" CACHE STRING "Use ZLib from compressed file" FORCE)

SET (SZIP_TGZ_NAME "SZip.tar.gz" CACHE STRING "Use SZip from compressed file" FORCE)

SET (JPEG_TGZ_NAME "JPEG8b.tar.gz" CACHE STRING "Use JPEG from compressed file" FORCE)

SET (HDF4_TGZ_NAME "HDF4.tar.gz" CACHE STRING "Use HDF4 from compressed file" FORCE)

SET (HDF5_TGZ_NAME "HDF5.tar.gz" CACHE STRING "Use HDF5 from compressed file" FORCE)

==> h4h5tools-2.2.2.tar.gz: h4h5tools-2.2.2/config/cmake/cacheinit.cmake <==
# This is the CMakeCache file.

########################
# EXTERNAL cache entries
########################

SET (BUILD_SHARED_LIBS ON CACHE BOOL "Build Shared Libraries" FORCE)

SET (USE_SHARED_LIBS ON CACHE BOOL "Use Shared Libraries" FORCE)

SET (BUILD_TESTING ON CACHE BOOL "Build H4H5 Unit Testing" FORCE)

SET (HDF_PACKAGE_EXT "" CACHE STRING "Name of HDF package extension" FORCE)

SET (HDF_BUILD_EXAMPLES ON CACHE BOOL "Build H4H5 Library Examples" FORCE)

SET (HDF_BUILD_TOOLS ON CACHE BOOL "Build H4H5 Tools" FORCE)

SET (HDF_BUILD_UTILS ON CACHE BOOL "Build H4H5 Library Utilities" FORCE)

SET (H4H5_ENABLE_EOS2 ON CACHE BOOL "Allow conversions of HDF4-EOS2 files" FORCE)

SET (H4H5_TEST_HDFEOS2 OFF CACHE BOOL "Test H4H5 EOS Library Utility" FORCE)

SET (HDF_ENABLE_JPEG_LIB_SUPPORT ON CACHE BOOL "Enable Jpeg library" FORCE)

SET (HDF_ENABLE_Z_LIB_SUPPORT ON CACHE BOOL "Enable Zlib Filters" FORCE)

SET (HDF_ENABLE_SZIP_SUPPORT ON CACHE BOOL "Use SZip Filter" FORCE)

SET (HDF_ENABLE_SZIP_ENCODING ON CACHE BOOL "Use SZip Encoding" FORCE)

SET (USE_HDF5_16_API_DEFAULT OFF CACHE BOOL "Use the HDF5 1.6.x API" FORCE)

SET (HDF_DISABLE_COMPILER_WARNINGS OFF CACHE BOOL "Disable compiler warnings" FORCE)

SET (HDF_ENABLE_PARALLEL OFF CACHE BOOL "Enable parallel build (requires MPI)" FORCE)

SET (HDF_ENABLE_COVERAGE OFF CACHE BOOL "Enable code coverage for Libraries and Programs" FORCE)

SET (HDF_PACKAGE_EXTLIBS OFF CACHE BOOL "(WINDOWS)CPACK - include external libraries" FORCE)

SET (HDF_ALLOW_EXTERNAL_SUPPORT "NO" CACHE STRING "Allow External Library Building" FORCE)

SET (ZLIB_SVN_URL "http://svn.hdfgroup.uiuc.edu/zlib/trunk" CACHE STRING "Use ZLib from HDF repository" FORCE)

SET (SZIP_SVN_URL "http://svn.hdfgroup.uiuc.edu/szip/trunk" CACHE STRING "Use SZip from HDF repository" FORCE)

SET (JPEG_SVN_URL "http://svn.hdfgroup.uiuc.edu/jpeg/branches/jpeg8b" CACHE STRING "Use JPEG from HDF repository" FORCE)

SET (HDF4_SVN_URL "http://svn.hdfgroup.uiuc.edu/hdf4/trunk" CACHE STRING "Use HDF4 from HDF repository" FORCE)

SET (HDF5_SVN_URL "http://svn.hdfgroup.uiuc.edu/hdf5/branches/hdf5_1_8" CACHE STRING "Use HDF5 from HDF repository" FORCE)

SET (ZLIB_TGZ_NAME "ZLib.tar.gz" CACHE STRING "Use ZLib from compressed file" FORCE)

SET (SZIP_TGZ_NAME "SZip.tar.gz" CACHE STRING "Use SZip from compressed file" FORCE)

SET (JPEG_TGZ_NAME "JPEG8b.tar.gz" CACHE STRING "Use JPEG from compressed file" FORCE)

SET (HDF4_TGZ_NAME "HDF4.tar.gz" CACHE STRING "Use HDF4 from compressed file" FORCE)

SET (HDF5_TGZ_NAME "HDF5.tar.gz" CACHE STRING "Use HDF5 from compressed file" FORCE)

SET (HDF4_PACKAGE_NAME "hdf4" CACHE STRING "Name of HDF4 package" FORCE)

SET (HDF5_PACKAGE_NAME "hdf5" CACHE STRING "Name of HDF5 package" FORCE)

SET (ZLIB_PACKAGE_NAME "zlib" CACHE STRING "Name of ZLIB package" FORCE)

SET (SZIP_PACKAGE_NAME "szip" CACHE STRING "Name of SZIP package" FORCE)

SET (JPEG_PACKAGE_NAME "jpeg" CACHE STRING "Name of JPEG package" FORCE)
